Crate kproc_pmacros

Crate kproc_pmacros 

stable pipeline dev/1 pipeline docs crates.io

auksys logo kproc

kproc is a knowledge processing library. It is intended to help transform information into a knowledge graph. This library is part of the auKsys project.

Development happens in the dev/1 branch. The latest stable release is available in the stable branch.

Derive Macros

InputStreams
Define input streams
OutputStreams
Define output streams
Processor
Define a processor